<a id="packages.valory.skills.abstract_abci.dialogues"></a>

# packages.valory.skills.abstract`_`abci.dialogues

This module contains the classes required for dialogue management.

<a id="packages.valory.skills.abstract_abci.dialogues.AbciDialogues"></a>

## AbciDialogues Objects

```python
class AbciDialogues(Model,  BaseAbciDialogues)
```

The dialogues class keeps track of all dialogues.

<a id="packages.valory.skills.abstract_abci.dialogues.AbciDialogues.__init__"></a>

#### `__`init`__`

```python
def __init__(**kwargs: Any) -> None
```

Initialize dialogues.

**Arguments**:

- `kwargs`: keyword arguments

